@@ -3,9 +3,9 @@
 #######################################
 import rips
 
-resinsight  = rips.Instance.find()
+resinsight = rips.Instance.find()
 
 if resinsight is None:
-    print('ERROR: could not find ResInsight')
+    print("ERROR: could not find ResInsight")
 else:
-	print('Successfully connected to ResInsight')
\ No newline at end of file
+    print("Successfully connected to ResInsight")
